@@ -8,7 +8,7 @@
  */
 
 /*  This file is part of AutoGen.
- *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2016 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -24,7 +24,16 @@
  * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifdef HAVE_SYS_RESOURCE_H
-#include <sys/resource.h>
+# include <sys/resource.h>
+#endif
+
+#ifdef SIGRTMIN
+# define MAX_AG_SIG SIGRTMIN-1
+#else
+# define MAX_AG_SIG NSIG
+#endif
+#ifndef SIGCHLD
+#  define SIGCHLD SIGCLD
 #endif
 
 typedef void (void_main_proc_t)(int, char **);
@@ -38,9 +47,6 @@ typedef enum {
 static char const * const state_names[] = { STATE_TABLE };
 #undef _State_
 
-static sigjmp_buf  abend_env;
-static int         abend_sig = 0;
-
 typedef void (sighandler_proc_t)(int sig);
 static sighandler_proc_t ignore_signal, catch_sig_and_bail;
 
@@ -51,7 +57,7 @@ inner_main(void * closure, int argc, char ** argv);
 static void
 exit_cleanup(wait_for_pclose_enum_t cl_wait);
 
-static void
+static _Noreturn void
 cleanup_and_abort(int sig);
 
 static void
@@ -64,9 +70,9 @@ static void
 done_check(void);
 
 static void
-setup_signals(sighandler_proc_t * chldHandler,
-              sighandler_proc_t * abrtHandler,
-              sighandler_proc_t * dfltHandler);
+setup_signals(sighandler_proc_t * hdl_chld,
+              sighandler_proc_t * hdl_abrt,
+              sighandler_proc_t * hdl_dflt);
 /* = = = END-STATIC-FORWARD = = = */
 
 #ifndef HAVE_CHMOD
@@ -96,18 +102,18 @@ inner_main(void * closure, int argc, char ** argv)
     processing_state = PROC_STATE_LOAD_TPL;
 
     {
-        templ_t* pTF = tpl_load(tpl_fname, NULL);
+        templ_t * tpl = tpl_load(tpl_fname, NULL);
 
         processing_state = PROC_STATE_EMITTING;
-        process_tpl(pTF);
+        process_tpl(tpl);
 
         processing_state = PROC_STATE_CLEANUP;
-        cleanup(pTF);
+        cleanup(tpl);
     }
 
     processing_state = PROC_STATE_DONE;
     setup_signals(SIG_DFL, SIG_IGN, SIG_DFL);
-    exit_code = AUTOGEN_EXIT_SUCCESS;
+    ag_exit_code = AUTOGEN_EXIT_SUCCESS;
     done_check();
     /* NOTREACHED */
     (void)closure;
@@ -123,13 +129,16 @@ inner_main(void * closure, int argc, char ** argv)
 int
 main(int argc, char ** argv)
 {
-    /*
-     *  IF we've been kicked with a signal,
-     *  THEN abort, passing the signal that whacked us.
-     */
-    if (sigsetjmp(abend_env, 0) != 0)
-        cleanup_and_abort(abend_sig);
+    {
+        char const * lc = getenv("LC_ALL");
+        if ((lc != NULL) && (*lc != NUL) && (strcmp(lc, "C") != 0)) {
+            putenv("LC_ALL=C");
+            execvp(argv[0], argv);
+            fserr(AUTOGEN_EXIT_FS_ERROR, "execvp", argv[0]);
+        }
+    }
 
+    // setlocale(LC_ALL, "");
     setup_signals(ignore_signal, SIG_DFL, catch_sig_and_bail);
     optionSaveState(&autogenOptions);
     trace_fp = stderr;
@@ -137,7 +146,7 @@ main(int argc, char ** argv)
 
     AG_SCM_BOOT_GUILE(argc, argv, inner_main);
 
-    /* NOT REACHED */
+    /* NOTREACHED */
     return EXIT_FAILURE;
 }
 
@@ -193,6 +202,7 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
         }
     } while (false);
 
+    trace_fp = stderr;
     fflush(stdout);
     fflush(stderr);
 }
@@ -203,13 +213,12 @@ exit_cleanup(wait_for_pclose_enum_t cl_wait)
  *
  *  @param[in] sig the signal number
  */
-static void
+static _Noreturn void
 cleanup_and_abort(int sig)
 {
-    int sig_exit_code = AUTOGEN_EXIT_SIGNAL + sig;
     if (processing_state == PROC_STATE_INIT) {
         fprintf(stderr, AG_NEVER_STARTED, sig, strsignal(sig));
-        exit(sig_exit_code);
+        exit(AUTOGEN_EXIT_SIGNAL + sig);
     }
 
     if (*oops_pfx != NUL) {
@@ -223,7 +232,7 @@ cleanup_and_abort(int sig)
 
     if (processing_state == PROC_STATE_ABORTING) {
         exit_cleanup(EXIT_PCLOSE_NOWAIT);
-        exit(sig_exit_code);
+        abort();
     }
 
     processing_state = PROC_STATE_ABORTING;
@@ -288,15 +297,13 @@ catch_sig_and_bail(int sig)
 {
     switch (processing_state) {
     case PROC_STATE_ABORTING:
-        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
+        ag_exit_code = AUTOGEN_EXIT_SIGNAL + sig;
 
     case PROC_STATE_DONE:
         break;
 
     default:
-        abend_sig = sig;
-        exit_code = AUTOGEN_EXIT_SIGNAL + sig;
-        siglongjmp(abend_env, sig);
+        cleanup_and_abort(sig);
     }
 }
 
@@ -356,9 +363,6 @@ done_check(void)
             oops_pfx = zNil;
         }
 
-        if (OPT_VALUE_TRACE > TRACE_NOTHING)
-            scm_backtrace();
-
         fprintf(stderr, SCHEME_EVAL_ERR_FMT, current_tpl->td_file,
                 cur_macro->md_line);
 
@@ -372,11 +376,11 @@ done_check(void)
             out_close(true);
 #endif
         } while (cur_fpstack->stk_prev != NULL);
-        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
+        ag_exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
         break; /* continue failure exit */
 
     case PROC_STATE_LOAD_DEFS:
-        exit_code = AUTOGEN_EXIT_BAD_DEFINITIONS;
+        ag_exit_code = AUTOGEN_EXIT_BAD_DEFINITIONS;
         /* FALLTHROUGH */
 
     default:
@@ -384,7 +388,7 @@ done_check(void)
         goto autogen_aborts;
 
     case PROC_STATE_ABORTING:
-        exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
+        ag_exit_code = AUTOGEN_EXIT_BAD_TEMPLATE;
 
     autogen_aborts:
         if (*oops_pfx != NUL) {
@@ -416,7 +420,8 @@ done_check(void)
     if (cgi_stderr != NULL) {
         do {
             long pos = ftell(stderr);
-            char* pz;
+            char * pz;
+            size_t rdlen;
 
             /*
              *  Don't bother with the overhead if there is no work to do.
@@ -425,8 +430,8 @@ done_check(void)
                 break;
             pz = AGALOC(pos, "stderr redir");
             rewind(stderr);
-            fread( pz, (size_t)1, (size_t)pos, stderr);
-            fwrite(pz, (size_t)1, (size_t)pos, stdout);
+            rdlen = fread( pz, (size_t)1, (size_t)pos, stderr);
+            fwrite(pz, (size_t)1, rdlen, stdout);
             AGFREE(pz);
         } while (false);
 
@@ -435,7 +440,7 @@ done_check(void)
         cgi_stderr = NULL;
     }
 
-    ag_scribble_deinit();
+    scribble_deinit();
 
     if (OPT_VALUE_TRACE > TRACE_NOTHING)
         fprintf(trace_fp, DONE_CHECK_DONE);
@@ -449,14 +454,14 @@ done_check(void)
      *  of inner_main().)
      */
     if (processing_state != PROC_STATE_OPTIONS)
-        exit(exit_code);
+        exit(ag_exit_code);
 }
 
 
-LOCAL void
-ag_abend_at(char const * pzMsg
+LOCAL _Noreturn void
+ag_abend_at(char const * msg
 #ifdef DEBUG_ENABLED
-            , char const * pzFile, int line
+            , char const * fname, int line
 #endif
     )
 {
@@ -466,23 +471,23 @@ ag_abend_at(char const * pzMsg
     }
 
 #ifdef DEBUG_ENABLED
-    fprintf(stderr, "Giving up in %s line %d\n", pzFile, line);
+    fprintf(stderr, "Giving up in %s line %d\n", fname, line);
 #endif
 
     if ((processing_state >= PROC_STATE_LIB_LOAD) && (current_tpl != NULL)) {
         int l_no = (cur_macro == NULL) ? -1 : cur_macro->md_line;
         fprintf(stderr, ERROR_IN_TPL_FMT, current_tpl->td_file, l_no);
     }
-    fputs(pzMsg, stderr);
-    pzMsg += strlen(pzMsg);
-    if (pzMsg[-1] != NL)
+    fputs(msg, stderr);
+    msg += strlen(msg);
+    if (msg[-1] != NL)
         fputc(NL, stderr);
 
     {
-        proc_state_t oldState = processing_state;
+        proc_state_t o_state = processing_state;
         processing_state = PROC_STATE_ABORTING;
 
-        switch (oldState) {
+        switch (o_state) {
         case PROC_STATE_EMITTING:
         case PROC_STATE_INCLUDING:
         case PROC_STATE_CLEANUP:
@@ -495,19 +500,14 @@ ag_abend_at(char const * pzMsg
     }
 }
 
-
 static void
-setup_signals(sighandler_proc_t * chldHandler,
-              sighandler_proc_t * abrtHandler,
-              sighandler_proc_t * dfltHandler)
+setup_signals(sighandler_proc_t * hdl_chld,
+              sighandler_proc_t * hdl_abrt,
+              sighandler_proc_t * hdl_dflt)
 {
     struct sigaction  sa;
     int    sigNo  = 1;
-#ifdef SIGRTMIN
-    const int maxSig = SIGRTMIN-1;
-#else
-    const int maxSig = NSIG;
-#endif
+    int const maxSig = MAX_AG_SIG;
 
     sa.sa_flags   = 0;
     sigemptyset(&sa.sa_mask);
@@ -523,15 +523,12 @@ setup_signals(sighandler_proc_t * chldHandler,
              *  POSIX oversight.  Allowed to be fixed for next POSIX rev, tho
              *  it is "optional" to reset SIGCHLD on exec(2).
              */
-#ifndef SIGCHLD
-#  define SIGCHLD SIGCLD
-#endif
         case SIGCHLD:
-            sa.sa_handler = chldHandler;
+            sa.sa_handler = hdl_chld;
             break;
 
         case SIGABRT:
-            sa.sa_handler = abrtHandler;
+            sa.sa_handler = hdl_abrt;
             break;
 
             /*
@@ -578,19 +575,8 @@ setup_signals(sighandler_proc_t * chldHandler,
             sa.sa_handler = SIG_IGN;
             break;
 
-#ifdef DAEMON_ENABLED
-# error DAEMON-ization of AutoGen is not ready for prime time
-  Choke Me.
-        case SIGHUP:
-            if (HAVE_OPT(DAEMON)) {
-                sa.sa_handler = handleSighup;
-                break;
-            }
-            /* FALLTHROUGH */
-#endif
-
         default:
-            sa.sa_handler = dfltHandler;
+            sa.sa_handler = hdl_dflt;
         }
         sigaction(sigNo,  &sa, NULL);
     } while (++sigNo < maxSig);
@@ -608,10 +594,8 @@ LOCAL void *
 ao_malloc (size_t sz)
 {
     void * res = malloc(sz);
-    if (res == NULL) {
-        fprintf(stderr, MALLOC_FAIL_FMT, sz);
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, MALLOC_FAIL_FMT, sz);
     return res;
 }
 
@@ -620,10 +604,8 @@ LOCAL void *
 ao_realloc (void *p, size_t sz)
 {
     void * res = (p == NULL) ? malloc(sz) : realloc(p, sz);
-    if (res == NULL) {
-        fprintf(stderr, REALLOC_FAIL_FMT, sz, p);
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, REALLOC_FAIL_FMT, sz, p);
     return res;
 }
 
@@ -631,10 +613,8 @@ LOCAL char *
 ao_strdup (char const * str)
 {
     char * res = strdup(str);
-    if (res == NULL) {
-        fprintf(stderr, STRDUP_FAIL_FMT, (int)strlen(str));
-        exit(EXIT_FAILURE);
-    }
+    if (res == NULL)
+        die(AUTOGEN_EXIT_FS_ERROR, STRDUP_FAIL_FMT, (int)strlen(str));
     return res;
 }
 
