@@ -5,8 +5,12 @@
  *  index values for a list of provided names.  It also documents how
  *  to incorporate that hashing function into a generated C program.
  *
+ * @addtogroup autogen
+ * @{
+ */
+/*
  *  This file is part of AutoGen.
- *  Copyright (C) 1992-2013 Bruce Korb - all rights reserved
+ *  Copyright (C) 1992-2016 Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -65,9 +69,9 @@ ag_scm_make_gperf(SCM name, SCM hlist)
 {
     static bool do_cleanup = true;
 
-    char const * pzName  = ag_scm2zchars(name, "gperf name");
-    char const * pzList;
-    SCM          newline = AG_SCM_STR2SCM(NEWLINE, (size_t)1);
+    char const * gp_nam = ag_scm2zchars(name, "gp nm");
+    char const * h_list;
+    SCM          nl_scm = AG_SCM_STR2SCM(NEWLINE, (size_t)1);
 
     if (! AG_SCM_STRING_P(name))
         return SCM_UNDEFINED;
@@ -75,24 +79,24 @@ ag_scm_make_gperf(SCM name, SCM hlist)
     /*
      *  Construct the newline separated list of values
      */
-    hlist  = ag_scm_join(newline, hlist);
-    pzList = ag_scm2zchars(hlist, "hash list");
+    hlist  = ag_scm_join(nl_scm, hlist);
+    h_list = ag_scm2zchars(hlist, "hash list");
 
     /*
      *  Stash the concatenated list somewhere, hopefully without an alloc.
      */
     {
-        char * cmd = aprf(MK_GPERF_SCRIPT, zMakeProg, pzName, pzList);
+        char * cmd = aprf(MK_GPERF_SCRIPT, make_prog, gp_nam, h_list);
 
         /*
          *  Run the command and ignore the results.
          *  In theory, the program should be ready.
          */
-        pzList = shell_cmd(cmd);
+        h_list = shell_cmd(cmd);
         AGFREE(cmd);
 
-        if (pzList != NULL)
-            free((void *)pzList);
+        if (h_list != NULL)
+            free(VOIDP(h_list));
     }
 
     if (do_cleanup) {
@@ -140,12 +144,14 @@ ag_scm_gperf(SCM name, SCM str)
     else
         str = AG_SCM_STR02SCM(key2hash);
 
-    AGFREE((void *)cmd);
-    AGFREE((void *)key2hash);
+    AGFREE(cmd);
+    AGFREE(key2hash);
     return str;
 }
 #endif
-/*
+/**
+ * @}
+ *
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
