@@ -9,7 +9,7 @@
  */
 /*
  *  This file is part of AutoGen.
- *  AutoGen Copyright (C) 1992-2014 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (C) 1992-2016 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -32,6 +32,13 @@ tpl_text(templ_t * tpl, macro_t * mac);
 static void
 tpl_warning(templ_t * tpl, macro_t * mac, char const * msg);
 
+static char const *
+is_mac_entry_ok(bool * allocated, def_ent_t * ent,
+                int * code, templ_t * tpl, macro_t * mac);
+
+static void
+emit_insertion_file(char const * fname, FILE * outfp);
+
 static int
 expr_type(char * pz);
 /* = = = END-STATIC-FORWARD = = = */
@@ -49,7 +56,7 @@ scm2display(SCM s)
 
     switch (ag_scm_type_e(s)) {
     case GH_TYPE_BOOLEAN:
-        z[0] = AG_SCM_NFALSEP(s) ? '1' : '0'; z[1] = NUL;
+        z[0] = scm_is_true(s) ? '1' : '0'; z[1] = NUL;
         break;
 
     case GH_TYPE_STRING:
@@ -58,7 +65,7 @@ scm2display(SCM s)
         break;
 
     case GH_TYPE_CHAR:
-        z[0] = (char)AG_SCM_CHAR(s); z[1] = NUL; break;
+        z[0] = (char)SCM_CHAR(s); z[1] = NUL; break;
 
     case GH_TYPE_VECTOR:
         res = RESOLVE_SCM_VECTOR; break;
@@ -93,7 +100,7 @@ scm2display(SCM s)
         res = RESOLVE_SCM_EXACT; break;
 
     case GH_TYPE_UNDEFINED:
-        res = (char*)zNil; break;
+        res = (char *)zNil; break;
 
     default:
         res = RESOLVE_SCM_UNKNOWN; break;
@@ -120,6 +127,76 @@ tpl_warning(templ_t * tpl, macro_t * mac, char const * msg)
     fprintf(trace_fp, TPL_WARN_FMT, tpl->td_file, mac->md_line, msg);
 }
 
+/**
+ * eval_mac_expr() helper function.  Determine if the entry found is
+ * a text entry.  If not, we return an empty string.
+ *
+ * @param allocated  whether the returned string has been allocated
+ * @param ent        The macro entry we found.  Now testing validity.
+ * @param code       flag word to indicate we found a valid string
+ * @param tpl        the current template being parsed
+ * @param mac        the current macro being invoked
+ *
+ * @returns a pointer to the macro substitution text
+ */
+static char const *
+is_mac_entry_ok(bool * allocated, def_ent_t * ent,
+                int * code, templ_t * tpl, macro_t * mac)
+{
+    char const * res = (char *)zNil;
+
+    if ((*code & EMIT_IF_ABSENT) != 0)
+        return res;
+
+    if (  (ent->de_type != VALTYP_TEXT)
+       && ((*code & EMIT_PRIMARY_TYPE) == EMIT_VALUE)  ) {
+        tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
+        return res;
+    }
+
+    /*
+     *  Compute the expression string.  There are three possibilities:
+     *  1.  There is an expression string in the macro, but it must
+     *      be formatted with the text value.
+     *      Make sure we have a value.
+     *  2.  There is an expression string in the macro, but it is *NOT*
+     *      to be formatted.  Use it as is.  Do *NOT* verify that
+     *      the define value is text.
+     *  3.  There is no expression with the macro invocation.
+     *      The define value *must* be text.
+     */
+    if ((*code & EMIT_FORMATTED) != 0) {
+        /*
+         *  And make sure what we found is a text value
+         */
+        if (ent->de_type != VALTYP_TEXT) {
+            tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
+            return res;
+        }
+
+        *allocated = true;
+        res = aprf(tpl_text(tpl, mac), ent->de_val.dvu_text);
+    }
+
+    else if (mac->md_txt_off != 0)
+        res = tpl->td_text + mac->md_txt_off;
+
+    else {
+        /*
+         *  And make sure what we found is a text value
+         */
+        if (ent->de_type != VALTYP_TEXT) {
+            tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
+            return res;
+        }
+
+        res = ent->de_val.dvu_text;
+    }
+
+    *code &= EMIT_PRIMARY_TYPE;
+    return res;
+}
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 /**
  *  Evaluate an expression and return a string pointer.  Always.
@@ -198,55 +275,9 @@ eval_mac_expr(bool * allocated)
          *  OTHERWISE, we found an entry.  Make sure we were supposed to.
          */
         else {
-            if ((code & EMIT_IF_ABSENT) != 0)
-                return (char*)zNil;
-
-            if (  (ent->de_type != VALTYP_TEXT)
-               && ((code & EMIT_PRIMARY_TYPE) == EMIT_VALUE)  ) {
-                tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
-                return (char*)zNil;
-            }
-
-            /*
-             *  Compute the expression string.  There are three possibilities:
-             *  1.  There is an expression string in the macro, but it must
-             *      be formatted with the text value.
-             *      Make sure we have a value.
-             *  2.  There is an expression string in the macro, but it is *NOT*
-             *      to be formatted.  Use it as is.  Do *NOT* verify that
-             *      the define value is text.
-             *  3.  There is no expression with the macro invocation.
-             *      The define value *must* be text.
-             */
-            if ((code & EMIT_FORMATTED) != 0) {
-                /*
-                 *  And make sure what we found is a text value
-                 */
-                if (ent->de_type != VALTYP_TEXT) {
-                    tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
-                    return (char*)zNil;
-                }
-
-                *allocated = true;
-                text = aprf(tpl_text(tpl, mac), ent->de_val.dvu_text);
-            }
-
-            else if (mac->md_txt_off != 0)
-                text = tpl->td_text + mac->md_txt_off;
-
-            else {
-                /*
-                 *  And make sure what we found is a text value
-                 */
-                if (ent->de_type != VALTYP_TEXT) {
-                    tpl_warning(tpl, mac, EVAL_EXPR_BLOCK_IN_EVAL);
-                    return (char*)zNil;
-                }
-
-                text = ent->de_val.dvu_text;
-            }
-
-            code &= EMIT_PRIMARY_TYPE;
+            text = is_mac_entry_ok(allocated, ent, &code, tpl, mac);
+            if (text == zNil)
+                return text;
         }
     }
 
@@ -257,7 +288,7 @@ eval_mac_expr(bool * allocated)
     case EMIT_VALUE:
         assert(ent != NULL);
         if (*allocated) {
-            AGFREE((void*)text);
+            AGFREE(text);
             *allocated = false;
         }
 
@@ -269,7 +300,7 @@ eval_mac_expr(bool * allocated)
         SCM res = ag_eval(text);
 
         if (*allocated) {
-            AGFREE((void*)text);
+            AGFREE(text);
             *allocated = false;
         }
 
@@ -279,10 +310,10 @@ eval_mac_expr(bool * allocated)
 
     case EMIT_SHELL:
     {
-        char* pz = shell_cmd(text);
+        char * pz = shell_cmd(text);
 
         if (*allocated)
-            AGFREE((void*)text);
+            AGFREE(text);
 
         if (pz != NULL) {
             *allocated = true;
@@ -290,7 +321,7 @@ eval_mac_expr(bool * allocated)
         }
         else {
             *allocated = false;
-            text = (char*)zNil;
+            text = (char *)zNil;
         }
         break;
     }
@@ -321,7 +352,6 @@ ag_scm_error_source_line(void)
     return SCM_UNDEFINED;
 }
 
-
 /*=gfunc emit
  *
  * what: emit the text for each argument
@@ -342,10 +372,10 @@ ag_scm_emit(SCM val)
     switch (depth) {
     case 1:
     {
-        out_stack_t* pSaveFp;
+        out_stack_t * pSaveFp;
         unsigned long pnum;
 
-        if (! AG_SCM_NUM_P(val))
+        if (! scm_is_number(val))
             break;
 
         pSaveFp = cur_fpstack;
@@ -371,11 +401,11 @@ ag_scm_emit(SCM val)
         if (val == SCM_UNDEFINED)
             break;
 
-        if (AG_SCM_NULLP(val))
+        if (scm_is_null(val))
             break;
 
         if (AG_SCM_STRING_P(val)) {
-            fputs((char*)ag_scm2zchars(val, "emit val"), fp);
+            fputs((char *)ag_scm2zchars(val, "emit val"), fp);
             fflush(fp);
             break;
         }
@@ -400,6 +430,101 @@ ag_scm_emit(SCM val)
     return SCM_UNDEFINED;
 }
 
+/**
+ * read in a file and write it to the passed in file pointer.
+ *
+ * @param [in]  fname  the name of the file to read
+ * @param [in]  outfp  the file pointer to write the data to.
+ */
+static void
+emit_insertion_file(char const * fname, FILE * outfp)
+{
+    char * txt = load_file(fname);
+    if (txt == NULL) {
+        if (errno == 0)
+            errno = ENOENT;
+        fswarn("loading", fname);
+        return;
+    }
+    if (fputs(txt, outfp) < 0)
+        fserr(AUTOGEN_EXIT_FS_ERROR, "fputs", cur_fpstack->stk_fname);
+
+    if (fflush(outfp) < 0)
+        fserr(AUTOGEN_EXIT_FS_ERROR, "fflush", cur_fpstack->stk_fname);
+    AGFREE(txt);
+}
+
+/*=gfunc insert_file
+ *
+ * what: insert the contents of a (list of) files.
+ *
+ * exparg: alist, list of files to emit, , list
+ *
+ * doc:  Insert the contents of one or more files.
+=*/
+SCM
+ag_scm_insert_file(SCM val)
+{
+    static int depth = 0;
+    static FILE * fp;
+
+    switch (depth) {
+    case 1:
+    {
+        out_stack_t * pSaveFp;
+        unsigned long pnum;
+
+        if (! scm_is_number(val))
+            break;
+
+        pSaveFp = cur_fpstack;
+        pnum    = AG_SCM_TO_ULONG(val);
+
+        for (; pnum > 0; pnum--) {
+            pSaveFp = pSaveFp->stk_prev;
+            if (pSaveFp == NULL)
+                AG_ABEND(aprf(EMIT_INVAL_PORT, AG_SCM_TO_ULONG(val)));
+        }
+
+        fp = pSaveFp->stk_fp;
+        return SCM_UNDEFINED;
+    }
+
+    case 0:
+        fp = cur_fpstack->stk_fp; // initialize the first time through
+        break;
+    }
+
+    depth++;
+    for (;;) {
+        if (val == SCM_UNDEFINED)
+            break;
+
+        if (scm_is_null(val))
+            break;
+
+        if (AG_SCM_STRING_P(val)) {
+            emit_insertion_file(ag_scm2zchars(val, "emit val"), fp);
+            break;
+        }
+
+        switch (ag_scm_type_e(val)) {
+        case GH_TYPE_LIST:
+        case GH_TYPE_PAIR:
+            ag_scm_insert_file(SCM_CAR(val));
+            val = SCM_CDR(val);
+            continue;
+
+        default: break;
+        }
+
+        break;
+    }
+
+    depth--;
+    return SCM_UNDEFINED;
+}
+
 /**
  *  The global evaluation function.
  *
@@ -422,16 +547,16 @@ eval(char const * expr)
     switch (*expr) {
     case '(':
     case ';':
-        res = ag_eval((char*)expr);
+        res = ag_eval((char *)expr);
         break;
 
     case '`':
         AGDUPSTR(pzTemp, expr, "shell script");
         (void)span_quote(pzTemp);
         expr = shell_cmd(pzTemp);
-        AGFREE((void*)pzTemp);
-        res = AG_SCM_STR02SCM((char*)expr);
-        AGFREE((void*)expr);
+        AGFREE(pzTemp);
+        res = AG_SCM_STR02SCM((char *)expr);
+        AGFREE(expr);
         break;
 
     case '"':
@@ -443,9 +568,9 @@ eval(char const * expr)
         /* FALLTHROUGH */
 
     default:
-        res = AG_SCM_STR02SCM((char*)expr);
+        res = AG_SCM_STR02SCM((char *)expr);
         if (allocated)
-            AGFREE((void*)expr);
+            AGFREE(expr);
     }
 
     return res;
@@ -467,7 +592,7 @@ eval(char const * expr)
  *   macro is inferred.  The result of the expression evaluation
  *   (@pxref{expression syntax}) is written to the current output.
 =*/
-macro_t*
+macro_t *
 mFunc_Expr(templ_t * tpl, macro_t * mac)
 {
     bool allocated_str;
@@ -481,7 +606,7 @@ mFunc_Expr(templ_t * tpl, macro_t * mac)
     }
 
     if (allocated_str)
-        AGFREE((void*)pz);
+        AGFREE(pz);
 
     return mac + 1;
 }
@@ -526,7 +651,7 @@ macro_t *
 mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
 {
     char *        copy; /* next text dest   */
-    char const *  src     = (char const*)mac->md_txt_off; /* macro text */
+    char const *  src     = (char const *)mac->md_txt_off; /* macro text */
     size_t        src_len = (size_t)mac->md_res;          /* macro len  */
     char const *  end_src = src + src_len;
 
@@ -605,7 +730,7 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
         mac->md_txt_off = 0;
 
     } else {
-        char* pz = copy;
+        char * pz = copy;
         src_len = (size_t)(end_src - src);
 
         mac->md_txt_off = (uintptr_t)(copy - tpl->td_text);
@@ -621,7 +746,7 @@ mLoad_Expr(templ_t * tpl, macro_t * mac, char const ** ppzScan)
          *  THEN find the ending expression...
          */
         if ((mac->md_res & EMIT_ALWAYS) != 0) {
-            char* pzNextExpr = (char*)skip_expr(pz, src_len);
+            char * pzNextExpr = (char *)skip_expr(pz, src_len);
 
             /*
              *  The next expression must be within bounds and space separated
