@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for agen5
- * Generated Thu Apr 30 19:55:38 PDT 2015
+ * Generated Wed Apr 20 14:44:32 PDT 2016
  */
 #ifndef AGEN5_PROTO_H_GUARD
 #define AGEN5_PROTO_H_GUARD 1
@@ -10,7 +10,7 @@
  *  Extracted from agCgi.c
  */
 static void
-loadCgi(void);
+load_cgi(void);
 
 /*
  *  Extracted from agDep.c
